@@ -26,7 +26,7 @@ has multiValuesSeparator => ( is => 'rw', isa => 'Maybe[Str]' );
 has jail                 => ( is => 'rw' );
 has error                => ( is => 'rw' );
 
-our $VERSION = '2.0.13';
+our $VERSION = '2.18.0';
 our @builtCustomFunctions;
 
 ## @imethod protected build_jail()
@@ -45,7 +45,7 @@ sub build_jail {
     $self->useSafeJail(1) unless defined $self->useSafeJail;
 
     if ($require) {
-        foreach my $f ( split /[, ]+/, $require ) {
+        foreach my $f ( split /[,\s]+/, $require ) {
             if ( $f =~ /^[\w\:]+$/ ) {
                 eval "require $f";
             }
@@ -63,7 +63,9 @@ sub build_jail {
 
     if ($build) {
         @builtCustomFunctions =
-          $self->customFunctions ? split( /\s+/, $self->customFunctions ) : ();
+          $self->customFunctions
+          ? split( /[,\s]+/, $self->customFunctions )
+          : ();
         foreach (@builtCustomFunctions) {
             no warnings 'redefine';
             $api->logger->debug("Custom function: $_");
@@ -104,7 +106,7 @@ sub build_jail {
     }
 
     $self->jail->share_from( __PACKAGE__,
-        [ @builtCustomFunctions, '&encrypt', '&token', '&listMatch' ] );
+        [ @builtCustomFunctions, '&encrypt', '&decrypt', '&token', '&listMatch' ] );
 
     $self->jail->share_from( 'MIME::Base64', ['&encode_base64'] );
 
@@ -121,6 +123,10 @@ sub encrypt {
     return &Lemonldap::NG::Handler::Main::tsv->{cipher}->encrypt( $_[0], 1 );
 }
 
+sub decrypt {
+    return &Lemonldap::NG::Handler::Main::tsv->{cipher}->decrypt( $_[0] );
+}
+
 sub token {
     return $_[0] ? encrypt( join( ':', time, @_ ) ) : encrypt(time);
 }
